@@ -17,6 +17,7 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 #include "alarm.h"
+#include "alarmhistoryitem.h"
 #include "daemon.h"
 #include "mainwindow.h"
 #include "module_list.h"
@@ -32,6 +33,7 @@ MainWindow::MainWindow(QWidget *parent) :
 	setWindowTitle("EvilAlarm");
 	setAttribute(Qt::WA_Maemo5StackedWindow);
 
+	menuBar()->addAction(tr("Clear Alarm History"), this, SLOT(clearHistory()));
 	menuBar()->addAction(tr("About"), this, SLOT(about()));
 
 	QWidget *centerwidget = new QWidget(this);
@@ -49,6 +51,16 @@ MainWindow::MainWindow(QWidget *parent) :
 	layout1->addWidget(activate_alarm);
 	layout1->addWidget(time_button);
 
+	//show history items
+	history_scrollarea = new QScrollArea();
+	QWidget *history_widget = new QWidget();
+	history_layout = new QHBoxLayout();
+	history_layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
+	history_widget->setLayout(history_layout);
+	history_widget->setMinimumHeight(240);
+	history_scrollarea->setWidget(history_widget);
+	reloadHistory();
+
 	QHBoxLayout *layout2 = new QHBoxLayout();
 	QPushButton *settings_button = new QPushButton(tr("Settings"), this);
 	QPushButton *test_button = new QPushButton(tr("Test Alarm"), this);
@@ -57,6 +69,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
 	QVBoxLayout *layout0 = new QVBoxLayout(centerwidget);
 	layout0->addLayout(layout1);
+	layout0->addWidget(history_scrollarea);
 	layout0->addLayout(layout2);
 
 	setCentralWidget(centerwidget);
@@ -78,21 +91,28 @@ MainWindow::MainWindow(QWidget *parent) :
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About EvilAlarm"),
-		tr("<center><h1>EvilAlarm 0.6</h1>\
+		tr("<center><h1>EvilAlarm 0.7</h1>\
 An alarm clock which cannot be turned off while asleep\
 <small><p>&copy;2010, 2011 Christian Pulvermacher &lt;pulvermacher@gmx.de&gt;</p></small></center>\
 <p>This program is free software; License: <a href=\"http://www.gnu.org/licenses/gpl-2.0.html\">GNU GPL 2</a> or later.</p>"));
 }
 
+void MainWindow::setAlarmTime(QTime time)
+{
+	if(activate_alarm->isChecked()) //unset old alarm
+		activate_alarm->toggle();
+
+	//set new one
+	time_picker->setCurrentTime(time);
+	activate_alarm->toggle();
+}
 
 void MainWindow::showSettings()
 {
-	Settings *s = new Settings(this);
+	static Settings *s = new Settings(this);
 	s->show();
-	//Settings cleans up after itself
 }
 
-
 void MainWindow::testAlarm()
 {
 	//TODO: strange things happen here
@@ -127,10 +147,66 @@ void MainWindow::toggleAlarm()
 
 		Daemon::start();
 
+		const int minutes = (msecs/1000/60)%60;
+		const int hours = (msecs/1000/60/60);
+		QMaemo5InformationBox::information(this, tr("Time left until alarm: %1:%2")
+			.arg(hours, 2, 10, QChar('0'))
+			.arg(minutes, 2, 10, QChar('0')));
+
 	} else {
 		timer.stop();
 		Daemon::stop();
+		reloadHistory();
 	}
 
 	time_button->setEnabled(!activate_alarm->isChecked());
 }
+
+
+void MainWindow::reloadHistory()
+{
+	//remove any old items
+	for(int i = 0; i < history.count(); i++) {
+		AlarmHistoryItem* item = history[i];
+		history_layout->removeWidget(item);
+		delete item;
+	}
+	history.clear();
+
+	//load history
+	QSettings settings;
+	settings.beginGroup("history");
+	QStringList times = settings.childGroups();
+	times.sort(); //times are in HH:MM:SS format, so they are sorted correctly
+	foreach(QString time, times) {
+		if(!settings.contains(time + "/used")) {
+			continue; //just to be safe
+		}
+
+		int num_used = settings.value(time + "/used").toInt();
+		history.append(new AlarmHistoryItem(QTime::fromString(time), num_used, this));
+	}
+	settings.endGroup();
+
+	foreach(AlarmHistoryItem* item, history) {
+		item->updateItem(); //make sure we're using the correct normalization
+
+		history_layout->addWidget(item);
+		connect(item, SIGNAL(selected(QTime)),
+			this, SLOT(setAlarmTime(QTime)));
+	}
+}
+
+void MainWindow::clearHistory()
+{
+	int ret = QMessageBox::question(this, tr("EvilAlarm"),
+		tr("Do you really want to remove all history entries?"),
+		QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+	if(ret == QMessageBox::Yes) {
+		QSettings settings;
+		settings.remove("history");
+		settings.sync();
+
+		reloadHistory();
+	}
+}
