@@ -2,7 +2,7 @@
 #include <QtGui>
 
 AlarmBlubbelsSettings::AlarmBlubbelsSettings(QWidget *parent):
-	QWidget(parent)
+	ModuleSettings(parent)
 {
 	QGridLayout *layout = new QGridLayout(this);
 	layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
@@ -12,13 +12,13 @@ AlarmBlubbelsSettings::AlarmBlubbelsSettings(QWidget *parent):
 	QLabel *threshold_label = new QLabel(tr("Score needed to turn off alarm"));
 	threshold = new QSpinBox();
 	threshold->setRange(10, 9999);
+	threshold->setSingleStep(10);
 	threshold->setValue(settings.value("blubbels_threshold", 500).toInt());
 	layout->addWidget(threshold_label, 0, 0);
 	layout->addWidget(threshold, 0, 1);
 }
 
-//save any changes
-AlarmBlubbelsSettings::~AlarmBlubbelsSettings()
+void AlarmBlubbelsSettings::save()
 {
 	QSettings settings;
 	settings.setValue("blubbels_threshold", threshold->value());
