@@ -16,15 +16,17 @@
     with this program; if not, write to the Free Software Foundation, Inc.,
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
-#include "module_list.h"
 #include "settings.h"
+#include "module_list.h"
+#include "module_settings.h"
 
 #include <QtGui>
 
+#include <iostream>
+
 
 Settings::Settings(QWidget *parent):
-	QScrollArea(parent),
-	module_settings(0)
+	QScrollArea(parent)
 {
 	setWindowTitle(tr("Settings"));
 	setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -72,7 +74,7 @@ Settings::Settings(QWidget *parent):
 	layout->addWidget(alarm_timeout, row, 1);
 	row++;
 
-	QLabel *inactivity_timeout_label = new QLabel(tr("Restart alarm if phone not moved for"));
+	QLabel *inactivity_timeout_label = new QLabel(tr("Restart alarm if inactive for"));
 	inactivity_timeout = new QSpinBox();
 	inactivity_timeout->setSuffix(" s");
 	inactivity_timeout->setValue(settings.value("inactivity_timeout", INACTIVITY_TIMEOUT).toInt());
@@ -106,6 +108,11 @@ Settings::Settings(QWidget *parent):
 	layout->addWidget(fullscreen, row, 0, 1, 2);
 	row++;
 
+	prevent_device_lock = new QCheckBox(tr("Prevent device lock (aka. \"Secure Device\")"));
+	prevent_device_lock->setChecked(settings.value("prevent_device_lock", false).toBool());
+	layout->addWidget(prevent_device_lock, row, 0, 1, 2);
+	row++;
+
 	QLabel *module_label = new QLabel(tr("Alarm module"));
 	module = new QComboBox(this);
 	module->addItems(ModuleList::availableModules());
@@ -130,12 +137,7 @@ Settings::Settings(QWidget *parent):
 	widget->setLayout(layout);
 }
 
-void Settings::closeEvent(QCloseEvent*)
-{
-	save();
-	delete module_settings; //save module settings
-	deleteLater();
-}
+void Settings::closeEvent(QCloseEvent*) { save(); }
 
 void Settings::pickSoundFile()
 {
@@ -146,6 +148,8 @@ void Settings::pickSoundFile()
 
 void Settings::save()
 {
+	std::cout << "saving\n";
+
 	settings.setValue("module", module->currentText());
 	settings.setValue("sound_filename", sound_filename->valueText());
 	settings.setValue("max_volume", volume->value());
@@ -155,5 +159,13 @@ void Settings::save()
 	settings.setValue("snooze_time", snooze_time->value());
 	settings.setValue("num_snooze_max", num_snooze_max->value());
 	settings.setValue("fullscreen", fullscreen->isChecked());
+	settings.setValue("prevent_device_lock", prevent_device_lock->isChecked());
 	settings.sync();
+
+	//save module settings
+	for(int i = 0; i < module_settings_layout->count(); i++) {
+		ModuleSettings *module_settings = qobject_cast<ModuleSettings *>(module_settings_layout->itemAt(i)->widget());
+		if(module_settings != 0)
+			module_settings->save();
+	}
 }
